Coverage for src/abcd_graph/utils.py: 100%

1# Copyright (c) 2024 Jordan Barrett & Aleksander Wojnarowicz

2#

3# Permission is hereby granted, free of charge, to any person obtaining a copy

4# of this software and associated documentation files (the "Software"), to deal

5# in the Software without restriction, including without limitation the rights

6# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell

7# copies of the Software, and to permit persons to whom the Software is

8# furnished to do so, subject to the following conditions:

9#

10# The above copyright notice and this permission notice shall be included in all

11# copies or substantial portions of the Software.

12#

13# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR

14# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,

15# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE

16# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER

17# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,

18# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE

19# SOFTWARE.

20

21

22 import random

23 from functools import wraps

24 from typing import Callable

25

26 import numpy

27 from typing_extensions import (

28 ParamSpec,

29 TypeVar,

30)

31

32 P = ParamSpec("P")

33 R = TypeVar("R")

34

35

36 def seed(num: int) -> None:

37 random.seed(num)

38 numpy.random.seed(num)

39

40

41 def require(package_name: str) -> Callable[[Callable[P, R]], Callable[P, R]]:

42 def deco(func: Callable[P, R]) -> Callable[P, R]:

43 @wraps(func)

44 def wrapper(*args: P.args, **kwargs: P.kwargs) -> R:

45 try:

46 return func(*args, **kwargs)

47 except ImportError as e:

48 raise ImportError(

49 f"Package '{package_name}' is required to use '{func.__name__}'. Run "

50 f"`pip install abcd_graph[{package_name}]` to install it."

51 ) from e

52

53 return wrapper

54

55 return deco